@@ -6,25 +6,25 @@ use prima_datadog::Datadog;
 #[test]
 pub fn incr_with_literal() {
     let mock = mocks::incr_mock("test", &[]);
-    Datadog::new(mock, true, vec![]).incr("test", vec![]);
+    Datadog::new(mock, true).incr("test", vec![]);
 }
 
 #[test]
 pub fn incr_with_type() {
     let mock = mocks::incr_mock("test1_event", &[]);
-    Datadog::new(mock, true, vec![]).incr(common::TestEvent::Test1, vec![]);
+    Datadog::new(mock, true).incr(common::TestEvent::Test1, vec![]);
 }
 
 #[test]
 pub fn incr_with_literal_and_tags() {
     let mock = mocks::incr_mock("test", &["added:tag", "env:test"]);
-    Datadog::new(mock, true, ["env:test"]).incr("test", vec!["added:tag".to_string()]);
+    Datadog::new(mock, true).incr("test", vec!["added:tag".to_string()]);
 }
 
 #[test]
 pub fn incr_with_type_and_tags() {
     let mock = mocks::incr_mock("test1_event", &["added:tag", "env:test"]);
-    Datadog::new(mock, true, ["env:test"]).incr(common::TestEvent::Test1, vec!["added:tag".to_string()]);
+    Datadog::new(mock, true).incr(common::TestEvent::Test1, vec!["added:tag".to_string()]);
 }
 
 #[test]
